@@ -2,53 +2,45 @@ from typing import Any, Dict, List, Union
 
 from fastapi import FastAPI, UploadFile
 from fastapi._compat import (
-    ModelField,
     Undefined,
     _get_model_config,
     get_cached_model_fields,
-    get_model_fields,
-    is_bytes_sequence_annotation,
     is_scalar_field,
     is_uploadfile_sequence_annotation,
+    v1,
 )
+from fastapi._compat.shared import is_bytes_sequence_annotation
 from fastapi.testclient import TestClient
-from pydantic import BaseConfig, BaseModel, ConfigDict
+from pydantic import BaseModel, ConfigDict
 from pydantic.fields import FieldInfo
 
-from .utils import needs_pydanticv1, needs_pydanticv2
+from .utils import needs_py_lt_314, needs_pydanticv2
 
 
 @needs_pydanticv2
 def test_model_field_default_required():
+    from fastapi._compat import v2
+
     # For coverage
     field_info = FieldInfo(annotation=str)
-    field = ModelField(name="foo", field_info=field_info)
+    field = v2.ModelField(name="foo", field_info=field_info)
     assert field.default is Undefined
 
 
-@needs_pydanticv1
-def test_upload_file_dummy_with_info_plain_validator_function():
+def test_v1_plain_validator_function():
     # For coverage
-    assert UploadFile.__get_pydantic_core_schema__(str, lambda x: None) == {}
+    def func(v):  # pragma: no cover
+        return v
+
+    result = v1.with_info_plain_validator_function(func)
+    assert result == {}
 
 
-@needs_pydanticv1
-def test_union_scalar_list():
+def test_is_model_field():
     # For coverage
-    # TODO: there might not be a current valid code path that uses this, it would
-    # potentially enable query parameters defined as both a scalar and a list
-    # but that would require more refactors, also not sure it's really useful
-    from fastapi._compat import is_pv1_scalar_field
+    from fastapi._compat import _is_model_field
 
-    field_info = FieldInfo()
-    field = ModelField(
-        name="foo",
-        field_info=field_info,
-        type_=Union[str, List[int]],
-        class_validators={},
-        model_config=BaseConfig,
-    )
-    assert not is_pv1_scalar_field(field)
+    assert not _is_model_field(str)
 
 
 @needs_pydanticv2
@@ -141,21 +133,22 @@ def test_is_uploadfile_sequence_annotation():
     assert is_uploadfile_sequence_annotation(Union[List[str], List[UploadFile]])
 
 
+@needs_py_lt_314
 def test_is_pv1_scalar_field():
     # For coverage
-    class Model(BaseModel):
+    class Model(v1.BaseModel):
         foo: Union[str, Dict[str, Any]]
 
-    fields = get_model_fields(Model)
+    fields = v1.get_model_fields(Model)
     assert not is_scalar_field(fields[0])
 
 
 def test_get_model_fields_cached():
-    class Model(BaseModel):
+    class Model(v1.BaseModel):
         foo: str
 
-    non_cached_fields = get_model_fields(Model)
-    non_cached_fields2 = get_model_fields(Model)
+    non_cached_fields = v1.get_model_fields(Model)
+    non_cached_fields2 = v1.get_model_fields(Model)
     cached_fields = get_cached_model_fields(Model)
     cached_fields2 = get_cached_model_fields(Model)
     for f1, f2 in zip(cached_fields, cached_fields2):
